@@ -16,10 +16,11 @@ from PyQt5.QtCore import QT_VERSION_STR
 import os
 import subprocess
 from pip_install import install,uninstall,find_moudles
+from load_text import *
 
 init(autoreset=True)
 
-
+is_Chinese = False
 Ui_MainWindow,_ = loadUiType('sources/downloader.ui')
 Fast_link,_ = loadUiType('sources/fast_link.ui')
 Python_script,_ = loadUiType('sources/python_script.ui')
@@ -50,6 +51,7 @@ class PS(QtWidgets.QMainWindow,Python_script):
         super(PS, self).__init__()
         self.setupUi(self)
         self.pushButton.clicked.connect(self.runs)
+
     def runs(self):
         self.un.emit()
     def run_script(self):
@@ -68,10 +70,28 @@ class Fast(QtWidgets.QMainWindow,Fast_link):
 
         super(Fast, self).__init__()
         self.setupUi(self)
-        self.pushButton.clicked.connect(self.start_PS)
+        self.pushButton.clicked.connect(self.a.emit)
         self.pushButton_2.clicked.connect(self.b.emit)
-    def start_PS(self):
-        self.a.emit()
+        self.main_timer = QtCore.QTimer()
+        self.main_timer.timeout.connect(self.loadd)
+        self.main_timer.start(1)
+
+
+
+    def load(self,dic):
+
+
+        self.label.setText(dic['fastlink.label'])
+        self.pushButton.setText(dic['fastlink.pushButton'])
+        self.pushButton_2.setText(dic['fastlink.pushButton_2'])
+
+    def loadd(self):
+        if is_Chinese:
+            self.load(load('zh-cn.lang'))
+        else:
+            self.load(load('en-us.lang'))
+
+
 
 
 
@@ -79,6 +99,7 @@ class Fast(QtWidgets.QMainWindow,Fast_link):
 class window(QtWidgets.QMainWindow,Ui_MainWindow):
     signal = pyqtSignal()
     fast_link = pyqtSignal()
+    version = '1.6'
     def __init__(self):
 
 
@@ -111,10 +132,38 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
 
         self.timer = QTimer()
         self.timer.timeout.connect(self.write)
-        self.timer.start(500)
+        self.timer.start(1)
         self.log(f'[{time.ctime()}][main/Info] timer initlazing sucsess')
         self.log(
             f'[{time.ctime()}][main/Info] backend library:PyQt5 version {PYQT_VERSION_STR} build on Qt {QT_VERSION_STR}')
+
+
+    def loadt(self,dic):
+
+        self.groupBox.setTitle(dic['groupBox'])
+        self.label.setText(dic['label'])
+        self.label_2.setText(dic['label_2'])
+        self.pushButton.setText(dic['pushButton'])
+        self.groupBox_2.setTitle(dic['groupBox_2'])
+        self.label_3.setText(dic['label_3'])
+        self.label_4.setText(dic['label_4'])
+        self.pushButton_2.setText(dic['pushButton_2'])
+        self.label_5.setText(dic['label_5']+self.version)
+        self.groupBox_3.setTitle(dic['groupBox_3'])
+        self.checkBox.setText(dic['checkBox'])
+        self.groupBox_4.setTitle(dic['groupBox_4'])
+        self.checkBox_2.setText(dic['checkBox_2'])
+        self.checkBox_3.setText(dic['checkBox_3'])
+        self.groupBox_5.setTitle(dic['groupBox_5'])
+        self.groupBox_6.setTitle(dic['groupBox_6'])
+        self.pushButton_3.setText(dic['pushButton_3'])
+        self.setWindowTitle(dic['title'])
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), dic['tab_win.tab'])
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), dic['tab_win.tab_2'])
+        self.tabWidget_2.setTabText(self.tabWidget.indexOf(self.tab), dic['tab_win2.tab'])
+        self.tabWidget_2.setTabText(self.tabWidget.indexOf(self.tab_2), dic['tab_win2.tab_2'])
+        self.checkBox_4.setText(dic['checkBox_4'])
+
     def fast(self):
         self.log(
             f'[{time.ctime()}][main/Info] fast link started')
@@ -137,7 +186,6 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
     def opencmd(self):
         os.system('cmd')
     def fwa(self):
-
         self.close()
     def print(self):
         self.log(f'[{time.ctime()}][main/Info] stopping!')
@@ -164,6 +212,16 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         else:
             event.ignore()
     def write(self):
+        if self.checkBox_4.isChecked():
+            self.lang = load('zh-cn.lang')
+            self.loadt(self.lang)
+            is_Chinese == True
+
+        else:
+            self.lang = load('en-us.lang')
+            self.loadt(self.lang)
+            is_Chinese == False
+
 
         a = open('properties/settings.properties','w')
         dic = [None,None,None,None,None]
